#!/usr/bin/python

# Generate an HTML page containing information about MP3s in a
# directory.
#
# Usage: mp3tohtml.py <mp3_dir>
#
# Last version of this tool can be get from the GIT repository:
# http://git.wpitchoune.net/radio.git
#
# (c) 2015 Jean-Philippe Orsini  <jeanfi@gmail.com>

import glob
import sys
import eyeD3

if len(sys.argv) != 2:
    exit(1)

files = glob.glob(sys.argv[1] + "/**/*mp3")

print "<html>"
print "<head>"
print "<title>All songs</title>"

print "	<link rel=\"stylesheet\" type=\"text/css\" href=\"https://cdn.datatables.net/1.10.10/css/jquery.dataTables.min.css\">"
print "<script type=\"text/javascript\" language=\"javascript\" src=\"https://ajax.googleapis.com/ajax/libs/jquery/1.12.0/jquery.min.js\">"
print "	</script>"
print "	<script type=\"text/javascript\" language=\"javascript\" src=\"https://cdn.datatables.net/1.10.10/js/jquery.dataTables.min.js\">"
print " </script>"
print "<script>$(document).ready(function() { $('#songs').DataTable(); } );</script>"
print "</head>"

print "<body><h1>List of songs</h1>"

print "<table id='songs' class='display compact' width='100%'>"
print "<thead><tr><th>Artist</th><th>Album</th><th>Title</th><th>Comments</th></tr></thead>"
for f in files:
    tag = eyeD3.Tag()

    tag.link(f)

    print "\t<tr>"

    try:
        artist = tag.getArtist()
        print "\t\t<td>" + artist + "</td>"
    except UnicodeEncodeError:
        print "\t\t<td></td>"

    try:
        print "\t\t<td>" + tag.getAlbum() + "</td>"
    except UnicodeEncodeError:
        print "\t\t<td></td>"

    try:
        print "\t\t<td>" + tag.getTitle() + "</td>"
    except UnicodeEncodeError:
        print "\t\t<td></td>"

    print "\t\t<td>"
    comments = tag.getComments()
    for c in comments:
        print comments[0].comment
    print "\t\t</td>"

    print "\t</tr>"

print "</table>"
print "<footer>"
print "            <ul>"
print "                    <li><a href=\"mailto:proxyradio@wpitchoune.net\">Contact</a></li>"
print "            </ul>"
print "</footer>"
print "</body></html>"
